pub enum ExactSizeExprKind {
Constant(ConstantExpr),
FromMetadata(MetadataValue),
Max(Vec<ExactSizeExpr>),
Min(Vec<ExactSizeExpr>),
Plus(ExactSizeExpr, ExactSizeExpr),
Scale(ExactSizeExpr, ConstantExpr),
AlignTo {
base: ExactSizeExpr,
target_align: ExactSizeExpr,
},
IfInhabited {
ty: Ty,
then_size: ExactSizeExpr,
else_size: ExactSizeExpr,
},
}Variants
Constant(ConstantExpr)
An arbitrary constant of type usize.
FromMetadata(MetadataValue)
Layout information stored in the pointer metadata to this object.
Max(Vec<ExactSizeExpr>)
Min(Vec<ExactSizeExpr>)
Plus(ExactSizeExpr, ExactSizeExpr)
Scale(ExactSizeExpr, ConstantExpr)
AlignTo
The next multiple of target_align from base.
IfInhabited
A size expression that depens on whether the given type is inhabited.
Implementations
Sourceimpl ExactSizeExprKind
impl ExactSizeExprKind
pub fn is_constant(&self) -> bool
pub fn is_from_metadata(&self) -> bool
pub fn is_max(&self) -> bool
pub fn is_min(&self) -> bool
pub fn is_plus(&self) -> bool
pub fn is_scale(&self) -> bool
pub fn is_align_to(&self) -> bool
pub fn is_if_inhabited(&self) -> bool
Sourceimpl ExactSizeExprKind
impl ExactSizeExprKind
pub fn as_constant(&self) -> Option<&ConstantExpr>
pub fn as_from_metadata(&self) -> Option<&MetadataValue>
pub fn as_max(&self) -> Option<&Vec<ExactSizeExpr>>
pub fn as_min(&self) -> Option<&Vec<ExactSizeExpr>>
pub fn as_plus(&self) -> Option<(&ExactSizeExpr, &ExactSizeExpr)>
pub fn as_scale(&self) -> Option<(&ExactSizeExpr, &ConstantExpr)>
pub fn as_align_to(&self) -> Option<(&ExactSizeExpr, &ExactSizeExpr)>
pub fn as_if_inhabited(&self) -> Option<(&Ty, &ExactSizeExpr, &ExactSizeExpr)>
Sourceimpl ExactSizeExprKind
impl ExactSizeExprKind
pub fn as_constant_mut(&mut self) -> Option<&mut ConstantExpr>
pub fn as_from_metadata_mut(&mut self) -> Option<&mut MetadataValue>
pub fn as_max_mut(&mut self) -> Option<&mut Vec<ExactSizeExpr>>
pub fn as_min_mut(&mut self) -> Option<&mut Vec<ExactSizeExpr>>
pub fn as_plus_mut( &mut self, ) -> Option<(&mut ExactSizeExpr, &mut ExactSizeExpr)>
pub fn as_scale_mut( &mut self, ) -> Option<(&mut ExactSizeExpr, &mut ConstantExpr)>
pub fn as_align_to_mut( &mut self, ) -> Option<(&mut ExactSizeExpr, &mut ExactSizeExpr)>
pub fn as_if_inhabited_mut( &mut self, ) -> Option<(&mut Ty, &mut ExactSizeExpr, &mut ExactSizeExpr)>
Sourceimpl ExactSizeExprKind
impl ExactSizeExprKind
pub fn variant_name(&self) -> &'static str
Sourceimpl ExactSizeExprKind
impl ExactSizeExprKind
pub fn zero() -> Self
pub fn from_usize(value: u128) -> Self
pub fn into_expr(self) -> ExactSizeExpr