pub enum MetadataValue {
DynSize,
DynAlign,
SliceLength,
}Expand description
Layout information given by the metadata of an unsized type.
Variants
DynSize
For a DST with dyn Trait metadata, this refers to the size found in the metadata.
DynAlign
For a DST with dyn Trait metadata, this refers to the alignment found in the metadata.
SliceLength
For a DST with slice metadata, this refers to the length found in the metadata.
Implementations
Sourceimpl MetadataValue
impl MetadataValue
pub fn is_dyn_size(&self) -> bool
pub fn is_dyn_align(&self) -> bool
pub fn is_slice_length(&self) -> bool
Sourceimpl MetadataValue
impl MetadataValue
pub fn as_dyn_size(&self) -> Option<()>
pub fn as_dyn_align(&self) -> Option<()>
pub fn as_slice_length(&self) -> Option<()>
Sourceimpl MetadataValue
impl MetadataValue
pub fn as_dyn_size_mut(&mut self) -> Option<()>
pub fn as_dyn_align_mut(&mut self) -> Option<()>
pub fn as_slice_length_mut(&mut self) -> Option<()>
Sourceimpl MetadataValue
impl MetadataValue
pub fn variant_name(&self) -> &'static str