pub enum OffsetGuarantee {
AtOffsetZero,
GuaranteedAlignment(ExactSizeExpr),
ReprCField {
predecessor: Option<FieldId>,
},
}Expand description
Guaranteed facts about a field offset.
Variants
AtOffsetZero
Guaranteed to be at offset zero. This applies for repr(transparent) and in some repr(C) cases.
GuaranteedAlignment(ExactSizeExpr)
Guaranteed only to be aligned to the given expression.
ReprCField
This offset is computed by the layout algorithm for C: take the previous field offset, add the previous field size, and align to the current field alignment.
Implementations
Sourceimpl OffsetGuarantee
impl OffsetGuarantee
pub fn is_at_offset_zero(&self) -> bool
pub fn is_guaranteed_alignment(&self) -> bool
pub fn is_repr_cfield(&self) -> bool
Sourceimpl OffsetGuarantee
impl OffsetGuarantee
pub fn as_at_offset_zero(&self) -> Option<()>
pub fn as_guaranteed_alignment(&self) -> Option<&ExactSizeExpr>
pub fn as_repr_cfield(&self) -> Option<&Option<FieldId>>
Sourceimpl OffsetGuarantee
impl OffsetGuarantee
pub fn as_at_offset_zero_mut(&mut self) -> Option<()>
pub fn as_guaranteed_alignment_mut(&mut self) -> Option<&mut ExactSizeExpr>
pub fn as_repr_cfield_mut(&mut self) -> Option<&mut Option<FieldId>>
Sourceimpl OffsetGuarantee
impl OffsetGuarantee
pub fn variant_name(&self) -> &'static str