pub enum SizeExprKind {
Constant(ConstantExpr),
FromMetadata(MetadataValue),
Max(Vec<SizeExpr>),
Min(Vec<SizeExpr>),
Plus(SizeExpr, SizeExpr),
Scale(SizeExpr, ConstantExpr),
AtLeast(SizeExpr),
AlignTo {
base: SizeExpr,
target_align: SizeExpr,
},
IfInhabited {
ty: Ty,
then_size: SizeExpr,
else_size: SizeExpr,
},
}Variants
Constant(ConstantExpr)
An arbitrary constant of type usize.
FromMetadata(MetadataValue)
Layout information stored in the pointer metadata to this object.
Max(Vec<SizeExpr>)
Min(Vec<SizeExpr>)
Plus(SizeExpr, SizeExpr)
Scale(SizeExpr, ConstantExpr)
Multiply by a constant.
AtLeast(SizeExpr)
The size is at least the value of this expression.
AlignTo
The next multiple of target_align from base.
IfInhabited
A size expression that depens on whether the given type is inhabited.
Implementations
Sourceimpl SizeExprKind
impl SizeExprKind
pub fn is_constant(&self) -> bool
pub fn is_from_metadata(&self) -> bool
pub fn is_max(&self) -> bool
pub fn is_min(&self) -> bool
pub fn is_plus(&self) -> bool
pub fn is_scale(&self) -> bool
pub fn is_at_least(&self) -> bool
pub fn is_align_to(&self) -> bool
pub fn is_if_inhabited(&self) -> bool
Sourceimpl SizeExprKind
impl SizeExprKind
pub fn as_constant(&self) -> Option<&ConstantExpr>
pub fn as_from_metadata(&self) -> Option<&MetadataValue>
pub fn as_max(&self) -> Option<&Vec<SizeExpr>>
pub fn as_min(&self) -> Option<&Vec<SizeExpr>>
pub fn as_plus(&self) -> Option<(&SizeExpr, &SizeExpr)>
pub fn as_scale(&self) -> Option<(&SizeExpr, &ConstantExpr)>
pub fn as_at_least(&self) -> Option<&SizeExpr>
pub fn as_align_to(&self) -> Option<(&SizeExpr, &SizeExpr)>
pub fn as_if_inhabited(&self) -> Option<(&Ty, &SizeExpr, &SizeExpr)>
Sourceimpl SizeExprKind
impl SizeExprKind
pub fn as_constant_mut(&mut self) -> Option<&mut ConstantExpr>
pub fn as_from_metadata_mut(&mut self) -> Option<&mut MetadataValue>
pub fn as_max_mut(&mut self) -> Option<&mut Vec<SizeExpr>>
pub fn as_min_mut(&mut self) -> Option<&mut Vec<SizeExpr>>
pub fn as_plus_mut(&mut self) -> Option<(&mut SizeExpr, &mut SizeExpr)>
pub fn as_scale_mut(&mut self) -> Option<(&mut SizeExpr, &mut ConstantExpr)>
pub fn as_at_least_mut(&mut self) -> Option<&mut SizeExpr>
pub fn as_align_to_mut(&mut self) -> Option<(&mut SizeExpr, &mut SizeExpr)>
pub fn as_if_inhabited_mut( &mut self, ) -> Option<(&mut Ty, &mut SizeExpr, &mut SizeExpr)>
Sourceimpl SizeExprKind
impl SizeExprKind
pub fn variant_name(&self) -> &'static str